@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_ABSTRACT_SINGLE_DISK_ADAPTOR_H_
-#define _D_ABSTRACT_SINGLE_DISK_ADAPTOR_H_
+#ifndef D_ABSTRACT_SINGLE_DISK_ADAPTOR_H
+#define D_ABSTRACT_SINGLE_DISK_ADAPTOR_H
 
 #include "DiskAdaptor.h"
 
@@ -43,10 +43,10 @@ class DiskWriter;
 class FileAllocationIterator;
 
 class AbstractSingleDiskAdaptor : public DiskAdaptor {
-protected:
-  SharedHandle<DiskWriter> diskWriter;
-  uint64_t totalLength;
-  bool _readOnly;
+private:
+  SharedHandle<DiskWriter> diskWriter_;
+  off_t totalLength_;
+  bool readOnly_;
 public:
   AbstractSingleDiskAdaptor();
 
@@ -61,29 +61,25 @@ public:
   virtual void openExistingFile();
 
   virtual void writeData(const unsigned char* data, size_t len,
-			 off_t offset);
+                         off_t offset);
 
   virtual ssize_t readData(unsigned char* data, size_t len, off_t offset);
 
   virtual bool fileExists();
 
-  virtual uint64_t size();
+  virtual off_t size();
 
-  virtual void truncate(uint64_t length);
+  virtual void truncate(off_t length);
   
   virtual SharedHandle<FileAllocationIterator> fileAllocationIterator();
 
-  virtual void enableDirectIO();
-
-  virtual void disableDirectIO();
-  
   // Make sure that DiskWriter is set before calling this function.
   virtual void enableReadOnly();
 
   // Make sure that DiskWriter is set before calling this function.
   virtual void disableReadOnly();
     
-  virtual bool isReadOnlyEnabled() const { return _readOnly; }
+  virtual bool isReadOnlyEnabled() const { return readOnly_; }
   
   virtual void cutTrailingGarbage();
 
@@ -91,13 +87,19 @@ public:
 
   void setDiskWriter(const SharedHandle<DiskWriter>& diskWriter);
 
-  SharedHandle<DiskWriter> getDiskWriter() const;
+  const SharedHandle<DiskWriter>& getDiskWriter() const
+  {
+    return diskWriter_;
+  }
 
-  void setTotalLength(const uint64_t& totalLength);
+  void setTotalLength(const off_t& totalLength);
 
-  uint64_t getTotalLength() const;
+  off_t getTotalLength() const
+  {
+    return totalLength_;
+  }
 };
 
 } // namespace aria2
 
-#endif // _D_ABSTRACT_SINGLE_DISK_ADAPTOR_H_
+#endif // D_ABSTRACT_SINGLE_DISK_ADAPTOR_H
