@@ -32,12 +32,12 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_ACTIVE_PEER_CONNECTION_COMMAND_H_
-#define _D_ACTIVE_PEER_CONNECTION_COMMAND_H_
+#ifndef D_ACTIVE_PEER_CONNECTION_COMMAND_H
+#define D_ACTIVE_PEER_CONNECTION_COMMAND_H
 
 #include "Command.h"
 #include "SharedHandle.h"
-#include "TimeA2.h"
+#include "TimerA2.h"
 
 namespace aria2 {
 
@@ -51,18 +51,18 @@ class BtAnnounce;
 
 class ActivePeerConnectionCommand : public Command {
 private:
-  RequestGroup* _requestGroup;
-  SharedHandle<BtRuntime> _btRuntime;
-  SharedHandle<PieceStorage> _pieceStorage;
-  SharedHandle<PeerStorage> _peerStorage;
-  SharedHandle<BtAnnounce> _btAnnounce;
+  RequestGroup* requestGroup_;
+  SharedHandle<BtRuntime> btRuntime_;
+  SharedHandle<PieceStorage> pieceStorage_;
+  SharedHandle<PeerStorage> peerStorage_;
+  SharedHandle<BtAnnounce> btAnnounce_;
 
-  time_t interval; // UNIT: sec
-  DownloadEngine* e;
-  Time checkPoint;
-  unsigned int _numNewConnection; // the number of the connection to establish.
+  time_t interval_; // UNIT: sec
+  DownloadEngine* e_;
+  Timer checkPoint_;
+  int numNewConnection_; // the number of the connection to establish.
 public:
-  ActivePeerConnectionCommand(int cuid,
+  ActivePeerConnectionCommand(cuid_t cuid,
                               RequestGroup* requestGroup,
                               DownloadEngine* e,
                               time_t interval);
@@ -73,9 +73,9 @@ public:
 
   void connectToPeer(const SharedHandle<Peer>& peer);
 
-  void setNumNewConnection(size_t numNewConnection)
+  void setNumNewConnection(int numNewConnection)
   {
-    _numNewConnection = numNewConnection;
+    numNewConnection_ = numNewConnection;
   }
 
   void setBtRuntime(const SharedHandle<BtRuntime>& btRuntime);
@@ -89,4 +89,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_ACTIVE_PEER_CONNECTION_COMMAND_H_
+#endif // D_ACTIVE_PEER_CONNECTION_COMMAND_H
