@@ -44,7 +44,7 @@ using namespace aria2::expr;
 
 namespace aria2 {
 
-BitfieldMan::BitfieldMan(size_t blockLength, uint64_t totalLength)
+BitfieldMan::BitfieldMan(int32_t blockLength, off_t totalLength)
   :blockLength_(blockLength),
    totalLength_(totalLength),
    bitfieldLength_(0),
@@ -60,7 +60,7 @@ BitfieldMan::BitfieldMan(size_t blockLength, uint64_t totalLength)
    cachedFilteredTotalLength_(0)
 {
   if(blockLength_ > 0 && totalLength_ > 0) {
-    blocks_ = totalLength_/blockLength_+(totalLength_%blockLength_ ? 1 : 0);
+    blocks_ = (totalLength_+blockLength_-1)/blockLength_;
     bitfieldLength_ = blocks_/8+(blocks_%8 ? 1 : 0);
     bitfield_ = new unsigned char[bitfieldLength_];
     useBitfield_ = new unsigned char[bitfieldLength_];
@@ -130,12 +130,12 @@ BitfieldMan::~BitfieldMan() {
   delete [] filterBitfield_;
 }
 
-size_t BitfieldMan::getLastBlockLength() const
+int32_t BitfieldMan::getLastBlockLength() const
 {
   return totalLength_-blockLength_*(blocks_-1);
 }
 
-size_t BitfieldMan::getBlockLength(size_t index) const
+int32_t BitfieldMan::getBlockLength(size_t index) const
 {
   if(index == blocks_-1) {
     return getLastBlockLength();
@@ -169,11 +169,11 @@ bool BitfieldMan::hasMissingPiece
 bool BitfieldMan::getFirstMissingUnusedIndex(size_t& index) const
 {
   if(filterEnabled_) {
-    return bitfield::getFirstMissingIndex
+    return bitfield::getFirstSetBitIndex
       (index, ~array(bitfield_)&~array(useBitfield_)&array(filterBitfield_),
        blocks_);
   } else {
-    return bitfield::getFirstMissingIndex
+    return bitfield::getFirstSetBitIndex
       (index, ~array(bitfield_)&~array(useBitfield_), blocks_);
   }
 }
@@ -182,11 +182,11 @@ size_t BitfieldMan::getFirstNMissingUnusedIndex
 (std::vector<size_t>& out, size_t n) const
 {
   if(filterEnabled_) {
-    return bitfield::getFirstNMissingIndex
+    return bitfield::getFirstNSetBitIndex
       (std::back_inserter(out), n,
        ~array(bitfield_)&~array(useBitfield_)&array(filterBitfield_), blocks_);
   } else {
-    return bitfield::getFirstNMissingIndex
+    return bitfield::getFirstNSetBitIndex
       (std::back_inserter(out), n,
        ~array(bitfield_)&~array(useBitfield_), blocks_);
   }
@@ -195,10 +195,10 @@ size_t BitfieldMan::getFirstNMissingUnusedIndex
 bool BitfieldMan::getFirstMissingIndex(size_t& index) const
 {
   if(filterEnabled_) {
-    return bitfield::getFirstMissingIndex
+    return bitfield::getFirstSetBitIndex
       (index, ~array(bitfield_)&array(filterBitfield_), blocks_);
   } else {
-    return bitfield::getFirstMissingIndex(index, ~array(bitfield_), blocks_);
+    return bitfield::getFirstSetBitIndex(index, ~array(bitfield_), blocks_);
   }
 }
 
@@ -230,10 +230,10 @@ namespace {
 template<typename Array>
 bool getSparseMissingUnusedIndex
 (size_t& index,
- size_t minSplitSize,
+ int32_t minSplitSize,
  const Array& bitfield,
  const unsigned char* useBitfield,
- size_t blockLength_,
+ int32_t blockLength,
  size_t blocks)
 {
   BitfieldMan::Range maxRange;
@@ -275,8 +275,8 @@ bool getSparseMissingUnusedIndex
     } else {
       if((!bitfield::test(useBitfield, blocks, maxRange.startIndex-1) &&
           bitfield::test(bitfield, blocks, maxRange.startIndex-1)) ||
-         ((uint64_t)(maxRange.endIndex-maxRange.startIndex)*blockLength_
-          >= minSplitSize)) {
+         (static_cast<int64_t>(maxRange.endIndex-maxRange.startIndex)*
+          blockLength >= minSplitSize)) {
         index = maxRange.startIndex;
         return true;
       } else {
@@ -291,7 +291,7 @@ bool getSparseMissingUnusedIndex
 
 bool BitfieldMan::getSparseMissingUnusedIndex
 (size_t& index,
- size_t minSplitSize,
+ int32_t minSplitSize,
  const unsigned char* ignoreBitfield,
  size_t ignoreBitfieldLength) const
 {
@@ -311,12 +311,75 @@ bool BitfieldMan::getSparseMissingUnusedIndex
 
 namespace {
 template<typename Array>
-bool getInorderMissingUnusedIndex
+bool getGeomMissingUnusedIndex
 (size_t& index,
- size_t minSplitSize,
+ int32_t minSplitSize,
  const Array& bitfield,
  const unsigned char* useBitfield,
- size_t blockLength_,
+ int32_t blockLength,
+ size_t blocks,
+ double base,
+ size_t offsetIndex)
+{
+  double start = 0;
+  double end = 1;
+  while(start+offsetIndex < blocks) {
+    index = blocks;
+    for(size_t i = start+offsetIndex,
+          eoi = std::min(blocks, static_cast<size_t>(end+offsetIndex));
+        i < eoi; ++i) {
+      if(bitfield::test(useBitfield, blocks, i)) {
+        break;
+      } else if(!bitfield::test(bitfield, blocks, i)) {
+        index = i;
+        break;
+      }
+    }
+    if(index < blocks) {
+      return true;
+    } else {
+      start = end;
+      end *= base;
+    }
+  }
+  return getSparseMissingUnusedIndex(index, minSplitSize,
+                                     bitfield, useBitfield,
+                                     blockLength, blocks);
+}
+} // namespace
+
+bool BitfieldMan::getGeomMissingUnusedIndex
+(size_t& index,
+ int32_t minSplitSize,
+ const unsigned char* ignoreBitfield,
+ size_t ignoreBitfieldLength,
+ double base,
+ size_t offsetIndex) const
+{
+  if(filterEnabled_) {
+    return aria2::getGeomMissingUnusedIndex
+      (index, minSplitSize,
+       array(ignoreBitfield)|~array(filterBitfield_)|
+       array(bitfield_)|array(useBitfield_),
+       useBitfield_, blockLength_, blocks_,
+       base, offsetIndex);
+  } else {
+    return aria2::getGeomMissingUnusedIndex
+      (index, minSplitSize,
+       array(ignoreBitfield)|array(bitfield_)|array(useBitfield_),
+       useBitfield_, blockLength_, blocks_,
+       base, offsetIndex);
+  }
+}
+
+namespace {
+template<typename Array>
+bool getInorderMissingUnusedIndex
+(size_t& index,
+ int32_t minSplitSize,
+ const Array& bitfield,
+ const unsigned char* useBitfield,
+ int32_t blockLength,
  size_t blocks)
 {
   // We always return first piece if it is available.
@@ -342,7 +405,7 @@ bool getInorderMissingUnusedIndex
            bitfield::test(useBitfield, blocks, j)) {
           break;
         }
-        if((j-i+1)*blockLength_ >= minSplitSize) {
+        if(static_cast<int64_t>(j-i+1)*blockLength >= minSplitSize) {
           index = j;
           return true;
         }
@@ -358,7 +421,7 @@ bool getInorderMissingUnusedIndex
 
 bool BitfieldMan::getInorderMissingUnusedIndex
 (size_t& index,
- size_t minSplitSize,
+ int32_t minSplitSize,
  const unsigned char* ignoreBitfield,
  size_t ignoreBitfieldLength) const
 {
@@ -600,7 +663,7 @@ void BitfieldMan::ensureFilterBitfield()
   }
 }
 
-void BitfieldMan::addFilter(uint64_t offset, uint64_t length) {
+void BitfieldMan::addFilter(off_t offset, off_t length) {
   ensureFilterBitfield();
   if(length > 0) {
     size_t startBlock = offset/blockLength_;
@@ -612,7 +675,7 @@ void BitfieldMan::addFilter(uint64_t offset, uint64_t length) {
   updateCache();
 }
 
-void BitfieldMan::removeFilter(uint64_t offset, uint64_t length) {
+void BitfieldMan::removeFilter(off_t offset, off_t length) {
   ensureFilterBitfield();
   if(length > 0) {
     size_t startBlock = offset/blockLength_;
@@ -624,7 +687,7 @@ void BitfieldMan::removeFilter(uint64_t offset, uint64_t length) {
   updateCache();
 }
 
-void BitfieldMan::addNotFilter(uint64_t offset, uint64_t length)
+void BitfieldMan::addNotFilter(off_t offset, off_t length)
 {
   ensureFilterBitfield();
   if(length > 0 && blocks_ > 0) {
@@ -663,7 +726,7 @@ void BitfieldMan::clearFilter() {
   updateCache();
 }
 
-uint64_t BitfieldMan::getFilteredTotalLengthNow() const {
+off_t BitfieldMan::getFilteredTotalLengthNow() const {
   if(!filterBitfield_) {
     return 0;
   }
@@ -672,13 +735,13 @@ uint64_t BitfieldMan::getFilteredTotalLengthNow() const {
     return 0;
   }
   if(bitfield::test(filterBitfield_, blocks_, blocks_-1)) {
-    return ((uint64_t)filteredBlocks-1)*blockLength_+getLastBlockLength();
+    return ((off_t)filteredBlocks-1)*blockLength_+getLastBlockLength();
   } else {
-    return ((uint64_t)filteredBlocks)*blockLength_;
+    return ((off_t)filteredBlocks)*blockLength_;
   }
 }
 
-uint64_t BitfieldMan::getCompletedLength(bool useFilter) const {
+off_t BitfieldMan::getCompletedLength(bool useFilter) const {
   unsigned char* temp;
   if(useFilter) {
     temp = new unsigned char[bitfieldLength_];
@@ -692,14 +755,15 @@ uint64_t BitfieldMan::getCompletedLength(bool useFilter) const {
     temp = bitfield_;
   }
   size_t completedBlocks = bitfield::countSetBit(temp, blocks_);
-  uint64_t completedLength = 0;
+  off_t completedLength = 0;
   if(completedBlocks == 0) {
     completedLength = 0;
   } else {
     if(bitfield::test(temp, blocks_, blocks_-1)) {
-      completedLength = ((uint64_t)completedBlocks-1)*blockLength_+getLastBlockLength();
+      completedLength =
+        ((off_t)completedBlocks-1)*blockLength_+getLastBlockLength();
     } else {
-      completedLength = ((uint64_t)completedBlocks)*blockLength_;
+      completedLength = ((off_t)completedBlocks)*blockLength_;
     }
   }
   if(useFilter) {
@@ -708,11 +772,11 @@ uint64_t BitfieldMan::getCompletedLength(bool useFilter) const {
   return completedLength;
 }
 
-uint64_t BitfieldMan::getCompletedLengthNow() const {
+off_t BitfieldMan::getCompletedLengthNow() const {
   return getCompletedLength(false);
 }
 
-uint64_t BitfieldMan::getFilteredCompletedLengthNow() const {
+off_t BitfieldMan::getFilteredCompletedLengthNow() const {
   return getCompletedLength(true);
 }
 
@@ -751,7 +815,7 @@ void BitfieldMan::setBitRange(size_t startIndex, size_t endIndex)
   updateCache();
 }
 
-bool BitfieldMan::isBitSetOffsetRange(uint64_t offset, uint64_t length) const
+bool BitfieldMan::isBitSetOffsetRange(off_t offset, off_t length) const
 {
   if(length <= 0) {
     return false;
@@ -772,12 +836,45 @@ bool BitfieldMan::isBitSetOffsetRange(uint64_t offset, uint64_t length) const
   return true;
 }
 
-uint64_t BitfieldMan::getMissingUnusedLength(size_t startingIndex) const
+off_t BitfieldMan::getOffsetCompletedLength
+(off_t offset,
+ off_t length) const
+{
+  off_t res = 0;
+  if(length == 0 || totalLength_ <= offset) {
+    return 0;
+  }
+  if(totalLength_ < offset+length) {
+    length = totalLength_-offset;
+  }
+  size_t start = offset/blockLength_;
+  size_t end = (offset+length-1)/blockLength_;
+  if(start == end) {
+    if(isBitSet(start)) {
+      res = length;
+    }
+  } else {
+    if(isBitSet(start)) {
+      res += (start+1)*blockLength_-offset;
+    }
+    for(size_t i = start+1; i <= end-1; ++i) {
+      if(isBitSet(i)) {
+        res += blockLength_;
+      }
+    }
+    if(isBitSet(end)) {
+      res += offset+length-end*blockLength_;
+    }
+  }
+  return res;
+}
+
+off_t BitfieldMan::getMissingUnusedLength(size_t startingIndex) const
 {
   if(startingIndex < 0 || blocks_ <= startingIndex) {
     return 0;
   }
-  uint64_t length = 0;
+  off_t length = 0;
   for(size_t i = startingIndex; i < blocks_; ++i) {
     if(isBitSet(i) || isUseBitSet(i)) {
       break;
