@@ -44,7 +44,6 @@
 #include "DlAbortEx.h"
 #include "message.h"
 #include "util.h"
-#include "StringFormat.h"
 #include "a2functional.h"
 
 namespace aria2 {
@@ -54,57 +53,57 @@ const std::string BtExtendedMessage::NAME("extended");
 BtExtendedMessage::BtExtendedMessage
 (const ExtensionMessageHandle& extensionMessage):
   SimpleBtMessage(ID, NAME),
-  _extensionMessage(extensionMessage),
-  _msg(0),
-  _msgLength(0)
+  extensionMessage_(extensionMessage),
+  msgLength_(0)
 {}
 
-BtExtendedMessage::~BtExtendedMessage()
-{
-  delete [] _msg;
-}
+BtExtendedMessage::~BtExtendedMessage() {}
 
-const unsigned char* BtExtendedMessage::getMessage() {
-  if(!_msg) {
-    /**
-     * len --- 2+extpayload.length, 4bytes
-     * id --- 20, 1byte
-     * extmsgid --- extmsgid, 1byte
-     * extpayload --- extpayload, nbytes
-     * total: 6+extpayload.length bytes
-     */
-    std::string payload = _extensionMessage->getPayload();
-    _msgLength = 6+payload.size();
-    _msg = new unsigned char[_msgLength];
-    bittorrent::createPeerMessageString(_msg, _msgLength, 2+payload.size(), ID);
-    *(_msg+5) = _extensionMessage->getExtensionMessageID();
-    memcpy(_msg+6, payload.c_str(), payload.size());
-  }
-  return _msg;
+unsigned char* BtExtendedMessage::createMessage()
+{
+  /**
+   * len --- 2+extpayload.length, 4bytes
+   * id --- 20, 1byte
+   * extmsgid --- extmsgid, 1byte
+   * extpayload --- extpayload, nbytes
+   * total: 6+extpayload.length bytes
+   */
+  std::string payload = extensionMessage_->getPayload();
+  msgLength_ = 6+payload.size();
+  unsigned char* msg = new unsigned char[msgLength_];
+  bittorrent::createPeerMessageString(msg, msgLength_, 2+payload.size(), ID);
+  *(msg+5) = extensionMessage_->getExtensionMessageID();
+  memcpy(msg+6, payload.data(), payload.size());
+  return msg;
 }
 
 size_t BtExtendedMessage::getMessageLength() {
-  getMessage();
-  return _msgLength;
+  if(!msgLength_) {
+    msgLength_ = 6+extensionMessage_->getPayload().size();
+  }
+  return msgLength_;
 }
 
 bool BtExtendedMessage::sendPredicate() const
 {
-  return peer->isExtendedMessagingEnabled();
+  return getPeer()->isExtendedMessagingEnabled();
 }
 
 std::string BtExtendedMessage::toString() const {
-  return strconcat(NAME, " ", _extensionMessage->toString());
+  std::string s = NAME;
+  s += " ";
+  s += extensionMessage_->toString();
+  return s;
 }
 
 BtExtendedMessageHandle
 BtExtendedMessage::create(const SharedHandle<ExtensionMessageFactory>& factory,
-                          const PeerHandle& peer,
+                          const SharedHandle<Peer>& peer,
                           const unsigned char* data, size_t dataLength)
 {
   bittorrent::assertPayloadLengthGreater(1, dataLength, NAME);
   bittorrent::assertID(ID, data, NAME);
-  assert(!factory.isNull());
+  assert(factory);
   ExtensionMessageHandle extmsg = factory->createMessage(data+1,
                                                          dataLength-1);
   BtExtendedMessageHandle message(new BtExtendedMessage(extmsg));
@@ -113,8 +112,8 @@ BtExtendedMessage::create(const SharedHandle<ExtensionMessageFactory>& factory,
 
 void BtExtendedMessage::doReceivedAction()
 {
-  if(!_extensionMessage.isNull()) {
-    _extensionMessage->doReceivedAction();
+  if(extensionMessage_) {
+    extensionMessage_->doReceivedAction();
   }
 }
 
