@@ -36,11 +36,12 @@
 #include "PieceStorage.h"
 #include "RequestGroup.h"
 #include "BtRuntime.h"
-#include "Peer.h"
-#include "DownloadContext.h"
 #include "Logger.h"
+#include "LogFactory.h"
 #include "wallclock.h"
 #include "util.h"
+#include "fmt.h"
+#include "DownloadEngine.h"
 
 namespace aria2 {
 
@@ -48,10 +49,10 @@ BtStopDownloadCommand::BtStopDownloadCommand
 (cuid_t cuid,
  RequestGroup* requestGroup,
  DownloadEngine* e,
- time_t timeout):
-  TimeBasedCommand(cuid, e, 1),
-  requestGroup_(requestGroup),
-  timeout_(timeout)
+ time_t timeout)
+  : TimeBasedCommand(cuid, e, 1),
+    requestGroup_(requestGroup),
+    timeout_(timeout)
 {}
 
 void BtStopDownloadCommand::preProcess()
@@ -59,11 +60,12 @@ void BtStopDownloadCommand::preProcess()
   if(btRuntime_->isHalt() || pieceStorage_->downloadFinished()) {
     enableExit();
   }
-  if(checkPoint_.difference(global::wallclock) >= timeout_) {
-    getLogger()->notice("GID#%s Stop downloading torrent due to"
-                        " --bt-stop-timeout option.",
-                        util::itos(requestGroup_->getGID()).c_str());
+  if(checkPoint_.difference(global::wallclock()) >= timeout_) {
+    A2_LOG_NOTICE(fmt(_("GID#%lld Stop downloading torrent due to"
+                        " --bt-stop-timeout option."),
+                      requestGroup_->getGID()));
     requestGroup_->setForceHaltRequested(true);
+    getDownloadEngine()->setRefreshInterval(0);
     enableExit();
   }
 }
@@ -71,7 +73,7 @@ void BtStopDownloadCommand::preProcess()
 void BtStopDownloadCommand::process()
 {
   if(requestGroup_->calculateStat().getDownloadSpeed() > 0) {
-    checkPoint_ = global::wallclock;
+    checkPoint_ = global::wallclock();
   }
 }
 
