@@ -32,29 +32,29 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_DHT_ABSTRACT_MESSAGE_H_
-#define _D_DHT_ABSTRACT_MESSAGE_H_
+#ifndef D_DHT_ABSTRACT_MESSAGE_H
+#define D_DHT_ABSTRACT_MESSAGE_H
 
 #include "DHTMessage.h"
 #include "A2STR.h"
+#include "ValueBase.h"
 
 namespace aria2 {
 
-class BDE;
 class DHTConnection;
 class DHTMessageDispatcher;
 class DHTMessageFactory;
 class DHTRoutingTable;
 
 class DHTAbstractMessage:public DHTMessage {
-protected:
-  WeakHandle<DHTConnection> _connection;
+private:
+  DHTConnection* connection_;
 
-  WeakHandle<DHTMessageDispatcher> _dispatcher;
+  DHTMessageDispatcher* dispatcher_;
 
-  WeakHandle<DHTMessageFactory> _factory;
+  DHTMessageFactory* factory_;
 
-  WeakHandle<DHTRoutingTable> _routingTable;
+  DHTRoutingTable* routingTable_;
 public:
   DHTAbstractMessage(const SharedHandle<DHTNode>& localNode,
                      const SharedHandle<DHTNode>& remoteNode,
@@ -64,21 +64,41 @@ public:
 
   virtual bool send();
 
-  virtual std::string getType() const = 0;
+  virtual const std::string& getType() const = 0;
 
-  virtual void fillMessage(BDE& msgDict) = 0;
+  virtual void fillMessage(Dict* msgDict) = 0;
 
   std::string getBencodedMessage();
 
-  void setConnection(const WeakHandle<DHTConnection>& connection);
+  DHTConnection* getConnection() const
+  {
+    return connection_;
+  }
 
-  void setMessageDispatcher(const WeakHandle<DHTMessageDispatcher>& dispatcher);
+  void setConnection(DHTConnection* connection);
+
+  DHTMessageDispatcher* getMessageDispatcher() const
+  {
+    return dispatcher_;
+  }
+
+  void setMessageDispatcher(DHTMessageDispatcher* dispatcher);
   
-  void setMessageFactory(const WeakHandle<DHTMessageFactory>& factory);
+  DHTMessageFactory* getMessageFactory() const
+  {
+    return factory_;
+  }
 
-  void setRoutingTable(const WeakHandle<DHTRoutingTable>& routingTable);
+  void setMessageFactory(DHTMessageFactory* factory);
+
+  DHTRoutingTable* getRoutingTable() const
+  {
+    return routingTable_;
+  }
+
+  void setRoutingTable(DHTRoutingTable* routingTable);
 };
 
 } // namespace aria2
 
-#endif // _D_DHT_ABSTRACT_MESSAGE_H_
+#endif // D_DHT_ABSTRACT_MESSAGE_H
