@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_DHT_GET_PEERS_REPLY_MESSAGE_H_
-#define _D_DHT_GET_PEERS_REPLY_MESSAGE_H_
+#ifndef D_DHT_GET_PEERS_REPLY_MESSAGE_H
+#define D_DHT_GET_PEERS_REPLY_MESSAGE_H
 
 #include "DHTResponseMessage.h"
 
@@ -47,15 +47,18 @@ class Peer;
 
 class DHTGetPeersReplyMessage:public DHTResponseMessage {
 private:
-  std::string _token;
+  int family_;
 
-  std::vector<SharedHandle<DHTNode> > _closestKNodes;
+  std::string token_;
 
-  std::vector<SharedHandle<Peer> > _values;
+  std::vector<SharedHandle<DHTNode> > closestKNodes_;
+
+  std::vector<SharedHandle<Peer> > values_;
 protected:
   virtual std::string toStringOptional() const;
 public:
-  DHTGetPeersReplyMessage(const SharedHandle<DHTNode>& localNode,
+  DHTGetPeersReplyMessage(int family,
+                          const SharedHandle<DHTNode>& localNode,
                           const SharedHandle<DHTNode>& remoteNode,
                           const std::string& token,
                           const std::string& transactionID);
@@ -64,36 +67,36 @@ public:
 
   virtual void doReceivedAction();
 
-  virtual BDE getResponse();
+  virtual SharedHandle<Dict> getResponse();
 
-  virtual std::string getMessageType() const;
+  virtual const std::string& getMessageType() const;
 
-  virtual void validate() const;
+  virtual void accept(DHTMessageCallback* callback);
 
   const std::vector<SharedHandle<DHTNode> >& getClosestKNodes() const
   {
-    return _closestKNodes;
+    return closestKNodes_;
   }
 
   const std::vector<SharedHandle<Peer> >& getValues() const
   {
-    return _values;
+    return values_;
   }
 
   void setClosestKNodes
   (const std::vector<SharedHandle<DHTNode> >& closestKNodes)
   {
-    _closestKNodes = closestKNodes;
+    closestKNodes_ = closestKNodes;
   }
 
   void setValues(const std::vector<SharedHandle<Peer> >& peers)
   {
-    _values = peers;
+    values_ = peers;
   }
   
   const std::string& getToken() const
   {
-    return _token;
+    return token_;
   }
 
   static const std::string GET_PEERS;
@@ -103,8 +106,10 @@ public:
   static const std::string VALUES;
 
   static const std::string NODES;
+
+  static const std::string NODES6;
 };
 
 } // namespace aria2
 
-#endif // _D_DHT_GET_PEERS_REPLY_MESSAGE_H_
+#endif // D_DHT_GET_PEERS_REPLY_MESSAGE_H
