@@ -41,56 +41,61 @@
 #include "LogFactory.h"
 #include "Logger.h"
 #include "DHTConstants.h"
-#include "StringFormat.h"
+#include "fmt.h"
 #include "DHTNode.h"
 
 namespace aria2 {
 
-DHTMessageDispatcherImpl::DHTMessageDispatcherImpl(const SharedHandle<DHTMessageTracker>& tracker):
-  _tracker(tracker),
-  _logger(LogFactory::getInstance()) {}
+DHTMessageDispatcherImpl::DHTMessageDispatcherImpl
+(const SharedHandle<DHTMessageTracker>& tracker)
+  : tracker_(tracker),
+    timeout_(DHT_MESSAGE_TIMEOUT)
+{}
 
 DHTMessageDispatcherImpl::~DHTMessageDispatcherImpl() {}
 
 void
-DHTMessageDispatcherImpl::addMessageToQueue(const SharedHandle<DHTMessage>& message,
-                                            time_t timeout,
-                                            const SharedHandle<DHTMessageCallback>& callback)
+DHTMessageDispatcherImpl::addMessageToQueue
+(const SharedHandle<DHTMessage>& message,
+ time_t timeout,
+ const SharedHandle<DHTMessageCallback>& callback)
 {
-  SharedHandle<DHTMessageEntry> e(new DHTMessageEntry(message, timeout, callback));
-  _messageQueue.push_back(e);
+  SharedHandle<DHTMessageEntry> e
+    (new DHTMessageEntry(message, timeout, callback));
+  messageQueue_.push_back(e);
 }
 
 void
-DHTMessageDispatcherImpl::addMessageToQueue(const SharedHandle<DHTMessage>& message,
-                                            const SharedHandle<DHTMessageCallback>& callback)
+DHTMessageDispatcherImpl::addMessageToQueue
+(const SharedHandle<DHTMessage>& message,
+ const SharedHandle<DHTMessageCallback>& callback)
 {
-  addMessageToQueue(message, DHT_MESSAGE_TIMEOUT, callback);
+  addMessageToQueue(message, timeout_, callback);
 }
 
 bool
-DHTMessageDispatcherImpl::sendMessage(const SharedHandle<DHTMessageEntry>& entry)
+DHTMessageDispatcherImpl::sendMessage
+(const SharedHandle<DHTMessageEntry>& entry)
 {
   try {
-    if(entry->_message->send()) {
-      if(!entry->_message->isReply()) {
-        _tracker->addMessage(entry->_message, entry->_timeout, entry->_callback);
-      }
-      if(_logger->info()) {
-        _logger->info("Message sent: %s", entry->_message->toString().c_str());
+    if(entry->message->send()) {
+      if(!entry->message->isReply()) {
+        tracker_->addMessage(entry->message, entry->timeout, entry->callback);
       }
+      A2_LOG_INFO(fmt("Message sent: %s", entry->message->toString().c_str()));
     } else {
       return false;
     }
   } catch(RecoverableException& e) {
-    _logger->info("Failed to send message: %s",
-                  e, entry->_message->toString().c_str());
+    A2_LOG_INFO_EX(fmt("Failed to send message: %s",
+                       entry->message->toString().c_str()),
+                   e);
     // Add message to DHTMessageTracker with timeout 0 to treat it as
     // time out. Without this, we have untracked message and some of
     // DHTTask(such as DHTAbstractNodeLookupTask) don't finish
     // forever.
-    if(!entry->_message->isReply()) {
-      _tracker->addMessage(entry->_message, 0, entry->_callback);
+    if(!entry->message->isReply()) {
+      tracker_->addMessage(entry->message, 0, entry->callback);
     }
   }
   return true;
@@ -101,22 +106,20 @@ void DHTMessageDispatcherImpl::sendMessages()
   // TODO I can't use bind1st and mem_fun here because bind1st cannot bind a
   // function which takes a reference as an argument..
   std::deque<SharedHandle<DHTMessageEntry> >::iterator itr =
-    _messageQueue.begin();
-  for(; itr != _messageQueue.end(); ++itr) {
+    messageQueue_.begin();
+  for(; itr != messageQueue_.end(); ++itr) {
     if(!sendMessage(*itr)) {
       break;
     }
   }
-  _messageQueue.erase(_messageQueue.begin(), itr);
-  if(_logger->debug()) {
-    _logger->debug("%lu dht messages remaining in the queue.",
-                   static_cast<unsigned long>(_messageQueue.size()));
-  }
+  messageQueue_.erase(messageQueue_.begin(), itr);
+  A2_LOG_DEBUG(fmt("%lu dht messages remaining in the queue.",
+                   static_cast<unsigned long>(messageQueue_.size())));
 }
 
 size_t DHTMessageDispatcherImpl::countMessageInQueue() const
 {
-  return _messageQueue.size();
+  return messageQueue_.size();
 }
 
 } // namespace aria2
