@@ -37,9 +37,7 @@
 #include "DlAbortEx.h"
 #include "HandshakeExtensionMessage.h"
 #include "UTPexExtensionMessage.h"
-#include "LogFactory.h"
-#include "Logger.h"
-#include "StringFormat.h"
+#include "fmt.h"
 #include "PeerStorage.h"
 #include "ExtensionMessageRegistry.h"
 #include "DownloadContext.h"
@@ -56,15 +54,18 @@
 
 namespace aria2 {
 
-DefaultExtensionMessageFactory::DefaultExtensionMessageFactory():
-  logger_(LogFactory::getInstance()) {}
+DefaultExtensionMessageFactory::DefaultExtensionMessageFactory()
+  : messageFactory_(0),
+    dispatcher_(0),
+    tracker_(0)
+{}
 
 DefaultExtensionMessageFactory::DefaultExtensionMessageFactory
 (const SharedHandle<Peer>& peer,
- const SharedHandle<ExtensionMessageRegistry>& registry):
-  peer_(peer),
-  registry_(registry),
-  logger_(LogFactory::getInstance()) {}
+ const SharedHandle<ExtensionMessageRegistry>& registry)
+  : peer_(peer),
+    registry_(registry)
+{}
 
 DefaultExtensionMessageFactory::~DefaultExtensionMessageFactory() {}
 
@@ -83,8 +84,8 @@ DefaultExtensionMessageFactory::createMessage(const unsigned char* data, size_t
     std::string extensionName = registry_->getExtensionName(extensionMessageID);
     if(extensionName.empty()) {
       throw DL_ABORT_EX
-        (StringFormat("No extension registered for extended message ID %u",
-                      extensionMessageID).str());
+        (fmt("No extension registered for extended message ID %u",
+             extensionMessageID));
     }
     if(extensionName == "ut_pex") {
       // uTorrent compatible Peer-Exchange
@@ -95,21 +96,22 @@ DefaultExtensionMessageFactory::createMessage(const unsigned char* data, size_t
     } else if(extensionName == "ut_metadata") {
       if(length == 0) {
         throw DL_ABORT_EX
-          (StringFormat(MSG_TOO_SMALL_PAYLOAD_SIZE,
-                        "ut_metadata",
-                        static_cast<unsigned long>(length)).str());
+          (fmt(MSG_TOO_SMALL_PAYLOAD_SIZE,
+               "ut_metadata",
+               static_cast<unsigned long>(length)));
       }
       size_t end;
-      SharedHandle<ValueBase> decoded = bencode2::decode(data+1, length-1, end);
-      const Dict* dict = asDict(decoded);
+      SharedHandle<ValueBase> decoded =
+        bencode2::decode(data+1, data+length, end);
+      const Dict* dict = downcast<Dict>(decoded);
       if(!dict) {
         throw DL_ABORT_EX("Bad ut_metadata: dictionary not found");
       }
-      const Integer* msgType = asInteger(dict->get("msg_type"));
+      const Integer* msgType = downcast<Integer>(dict->get("msg_type"));
       if(!msgType) {
         throw DL_ABORT_EX("Bad ut_metadata: msg_type not found");
       }
-      const Integer* index = asInteger(dict->get("piece"));
+      const Integer* index = downcast<Integer>(dict->get("piece"));
       if(!index) {
         throw DL_ABORT_EX("Bad ut_metadata: piece not found");
       }
@@ -128,7 +130,7 @@ DefaultExtensionMessageFactory::createMessage(const unsigned char* data, size_t
         if(end == length) {
           throw DL_ABORT_EX("Bad ut_metadata data: data not found");
         }
-        const Integer* totalSize = asInteger(dict->get("total_size"));
+        const Integer* totalSize = downcast<Integer>(dict->get("total_size"));
         if(!totalSize) {
           throw DL_ABORT_EX("Bad ut_metadata data: total_size not found");
         }
@@ -136,7 +138,7 @@ DefaultExtensionMessageFactory::createMessage(const unsigned char* data, size_t
           (new UTMetadataDataExtensionMessage(extensionMessageID));
         m->setIndex(index->i());
         m->setTotalSize(totalSize->i());
-        m->setData(std::string(&data[1+end], &data[length]));
+        m->setData(&data[1+end], &data[length]);
         m->setUTMetadataRequestTracker(tracker_);
         m->setPieceStorage(dctx_->getOwnerRequestGroup()->getPieceStorage());
         m->setDownloadContext(dctx_);
@@ -151,14 +153,14 @@ DefaultExtensionMessageFactory::createMessage(const unsigned char* data, size_t
       }
       default:
         throw DL_ABORT_EX
-          (StringFormat("Bad ut_metadata: unknown msg_type=%u",
-                        static_cast<unsigned int>(msgType->i())).str());
+          (fmt("Bad ut_metadata: unknown msg_type=%u",
+               static_cast<unsigned int>(msgType->i())));
       }
     } else {
       throw DL_ABORT_EX
-        (StringFormat("Unsupported extension message received."
-                      " extensionMessageID=%u, extensionName=%s",
-                      extensionMessageID, extensionName.c_str()).str());
+        (fmt("Unsupported extension message received."
+             " extensionMessageID=%u, extensionName=%s",
+             extensionMessageID, extensionName.c_str()));
     }
   }
 }
