@@ -120,7 +120,7 @@ private:
 
   bool noWait_;
 
-  static const int64_t DEFAULT_REFRESH_INTERVAL = 900;
+  static const int64_t DEFAULT_REFRESH_INTERVAL = 1000;
 
   // Milliseconds
   int64_t refreshInterval_;
@@ -135,6 +135,10 @@ private:
 
   CUIDCounter cuidCounter_;
 
+#ifdef HAVE_ARES_ADDR_NODE
+  ares_addr_node* asyncDNSServers_;
+#endif // HAVE_ARES_ADDR_NODE
+
   SharedHandle<DNSCache> dnsCache_;
 
   SharedHandle<AuthConfigFactory> authConfigFactory_;
@@ -326,6 +330,15 @@ public:
   {
     return sessionId_;
   }
+
+#ifdef HAVE_ARES_ADDR_NODE
+  void setAsyncDNSServers(ares_addr_node* asyncDNSServers);
+
+  ares_addr_node* getAsyncDNSServers() const
+  {
+    return asyncDNSServers_;
+  }
+#endif // HAVE_ARES_ADDR_NODE
 };
 
 typedef SharedHandle<DownloadEngine> DownloadEngineHandle;
