@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_DOWNLOAD_HANDLER_FACTORY_H_
-#define _D_DOWNLOAD_HANDLER_FACTORY_H_
+#ifndef D_DOWNLOAD_HANDLER_FACTORY_H
+#define D_DOWNLOAD_HANDLER_FACTORY_H
 
 #include "common.h"
 #include "SharedHandle.h"
@@ -54,21 +54,21 @@ class DownloadHandlerFactory
 private:
 #ifdef ENABLE_METALINK
   static SharedHandle<MemoryBufferPreDownloadHandler>
-  _metalinkPreDownloadHandler;
+  metalinkPreDownloadHandler_;
 
   static SharedHandle<MetalinkPostDownloadHandler>
-  _metalinkPostDownloadHandler;
+  metalinkPostDownloadHandler_;
 #endif // ENABLE_METALINK
 
 #ifdef ENABLE_BITTORRENT
   static SharedHandle<MemoryBufferPreDownloadHandler>
-  _btPreDownloadHandler;
+  btPreDownloadHandler_;
 
   static SharedHandle<BtPostDownloadHandler>
-  _btPostDownloadHandler;
+  btPostDownloadHandler_;
 
   static SharedHandle<UTMetadataPostDownloadHandler>
-  _btMetadataPostDownloadHandler;
+  btMetadataPostDownloadHandler_;
 #endif // ENABLE_BITTORRENT
 public:
 #ifdef ENABLE_METALINK
@@ -93,4 +93,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_DOWNLOAD_HANDLER_FACTORY_H_
+#endif // D_DOWNLOAD_HANDLER_FACTORY_H
