@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -38,32 +38,33 @@
 namespace aria2 {
 
 FallocFileAllocationIterator::FallocFileAllocationIterator
-(BinaryStream* stream, off_t offset, uint64_t totalLength):
-  _stream(stream), _offset(offset), _totalLength(totalLength) {}
+(BinaryStream* stream, off_t offset, off_t totalLength):
+  stream_(stream), offset_(offset), totalLength_(totalLength) {}
 
 void FallocFileAllocationIterator::allocateChunk()
 {
-  if(static_cast<uint64_t>(_offset) > _totalLength) {
-    throw DL_ABORT_EX("FallocFileAllocationIterator: offset is larger than"
-		    " totalLength");
+  if(offset_ < totalLength_) {
+    stream_->allocate(offset_, totalLength_-offset_);
+    offset_ = totalLength_;
+  } else {
+    stream_->truncate(totalLength_);
+    offset_ = totalLength_;
   }
-  _stream->allocate(_offset, _totalLength-_offset);
-  _offset = _totalLength;
 }
 
 bool FallocFileAllocationIterator::finished()
 {
-  return static_cast<uint64_t>(_offset) == _totalLength;
+  return offset_ == totalLength_;
 }
 
 off_t FallocFileAllocationIterator::getCurrentLength()
 {
-  return _offset;
+  return offset_;
 }
 
-uint64_t FallocFileAllocationIterator::getTotalLength()
+off_t FallocFileAllocationIterator::getTotalLength()
 {
-  return _totalLength;
+  return totalLength_;
 }
 
 } // namespace aria2
