@@ -37,6 +37,8 @@
 
 #include "AbstractCommand.h"
 
+#include <deque>
+
 namespace aria2 {
 
 class FtpConnection;
@@ -135,7 +137,7 @@ private:
 
   void poolConnection() const;
 
-  bool onFileSizeDetermined(uint64_t totalLength);
+  bool onFileSizeDetermined(off_t totalLength);
 
   void onDryRunFileFound();
 
@@ -145,8 +147,8 @@ private:
   SharedHandle<FtpConnection> ftp_;
   // For tunneling
   SharedHandle<HttpConnection> http_;
-  // IP, Port pair in pasv response
-  std::pair<std::string, uint16_t> dataConnAddr_;
+  // Port number in PASV/EPSV response
+  uint16_t pasvPort_;
   // Resolved address for proxy
   std::string proxyAddr_;
 
