@@ -38,6 +38,7 @@
 #include "common.h"
 
 #include <stdint.h>
+#include <vector>
 
 #include "SharedHandle.h"
 #include "TimeA2.h"
@@ -48,6 +49,9 @@ namespace aria2 {
 class HttpRequest;
 class HttpHeader;
 class StreamFilter;
+class MetalinkHttpEntry;
+class Option;
+class Checksum;
 
 class HttpResponse {
 private:
@@ -78,11 +82,11 @@ public:
 
   void processRedirect();
 
-  std::string getRedirectURI() const;
+  const std::string& getRedirectURI() const;
 
   bool isTransferEncodingSpecified() const;
 
-  std::string getTransferEncoding() const;
+  const std::string& getTransferEncoding() const;
 
   SharedHandle<StreamFilter> getTransferEncodingStreamFilter() const;
 
@@ -92,9 +96,9 @@ public:
 
   SharedHandle<StreamFilter> getContentEncodingStreamFilter() const;
 
-  uint64_t getContentLength() const;
+  off_t getContentLength() const;
 
-  uint64_t getEntityLength() const;
+  off_t getEntityLength() const;
 
   // Returns type "/" subtype. The parameter is removed.
   std::string getContentType() const;
@@ -127,6 +131,17 @@ public:
   Time getLastModifiedTime() const;
 
   bool supportsPersistentConnection() const;
+
+  void getMetalinKHttpEntries
+  (std::vector<MetalinkHttpEntry>& result,
+   const SharedHandle<Option>& option) const;
+#ifdef ENABLE_MESSAGE_DIGEST
+  // Returns all digests specified in Digest header field.  Sort
+  // strong algorithm first. Strength is defined in MessageDigest. If
+  // several same digest algorithms are available, but they have
+  // different value, they are all ignored.
+  void getDigest(std::vector<Checksum>& result) const;
+#endif // ENABLE_MESSAGE_DIGEST
 };
 
 } // namespace aria2
