@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_HTTP_SERVER_H_
-#define _D_HTTP_SERVER_H_
+#ifndef D_HTTP_SERVER_H
+#define D_HTTP_SERVER_H
 
 #include "common.h"
 
@@ -50,24 +50,25 @@ class SocketCore;
 class HttpHeader;
 class HttpHeaderProcessor;
 class DownloadEngine;
-class Logger;
+class SocketRecvBuffer;
 
 class HttpServer {
 private:
-  SharedHandle<SocketCore> _socket;
-  SocketBuffer _socketBuffer;
-  DownloadEngine* _e;
-  SharedHandle<HttpHeaderProcessor> _headerProcessor;
-  Logger* _logger;
-  SharedHandle<HttpHeader> _lastRequestHeader;
-  uint64_t _lastContentLength;
-  std::stringstream _lastBody;
-  bool _keepAlive;
-  bool _gzip;
-  std::string _username;
-  std::string _password;
-  bool _acceptsPersistentConnection;
-  bool _acceptsGZip;
+  SharedHandle<SocketCore> socket_;
+  SharedHandle<SocketRecvBuffer> socketRecvBuffer_;
+  SocketBuffer socketBuffer_;
+  DownloadEngine* e_;
+  SharedHandle<HttpHeaderProcessor> headerProcessor_;
+  SharedHandle<HttpHeader> lastRequestHeader_;
+  off_t lastContentLength_;
+  std::stringstream lastBody_;
+  bool keepAlive_;
+  bool gzip_;
+  std::string username_;
+  std::string password_;
+  bool acceptsPersistentConnection_;
+  bool acceptsGZip_;
+  std::string allowOrigin_;
 public:
   HttpServer(const SharedHandle<SocketCore>& socket, DownloadEngine* e);
 
@@ -79,23 +80,21 @@ public:
 
   std::string getBody() const;
 
+  const std::string& getMethod() const;
+
   const std::string& getRequestPath() const;
 
-  void feedResponse(const std::string& text, const std::string& contentType);
+  void feedResponse(std::string& text, const std::string& contentType);
 
   void feedResponse(const std::string& status,
                     const std::string& headers,
-                    const std::string& text,
+                    std::string& text,
                     const std::string& contentType);
 
   bool authenticate();
 
   void setUsernamePassword
-  (const std::string& username, const std::string& password)
-  {
-    _username = username;
-    _password = password;
-  }
+  (const std::string& username, const std::string& password);
 
   ssize_t sendResponse();
 
@@ -103,25 +102,35 @@ public:
 
   bool supportsPersistentConnection() const
   {
-    return _keepAlive && _acceptsPersistentConnection;
+    return keepAlive_ && acceptsPersistentConnection_;
   }
 
   bool supportsGZip() const
   {
-    return _gzip && _acceptsGZip;
+    return gzip_ && acceptsGZip_;
   }
 
-  void enableKeepAlive() { _keepAlive = true; }
+  void enableKeepAlive() { keepAlive_ = true; }
 
-  void disableKeepAlive() { _keepAlive = false; }
+  void disableKeepAlive() { keepAlive_ = false; }
 
-  void enableGZip() { _gzip = true; }
+  void enableGZip() { gzip_ = true; }
 
-  void disableGZip() { _gzip = false; }
+  void disableGZip() { gzip_ = false; }
 
-  uint64_t getContentLength() const { return _lastContentLength; }
+  off_t getContentLength() const { return lastContentLength_; }
+
+  const SharedHandle<SocketRecvBuffer>& getSocketRecvBuffer() const
+  {
+    return socketRecvBuffer_;
+  }
+
+  void setAllowOrigin(const std::string& allowOrigin)
+  {
+    allowOrigin_ = allowOrigin;
+  }
 };
 
 } // namespace aria2
 
-#endif // _D_HTTP_SERVER_H_
+#endif // D_HTTP_SERVER_H
