@@ -94,8 +94,8 @@ void HttpSkipResponseCommand::installStreamFilter
   }
   streamFilter->installDelegate(streamFilter_);
   streamFilter_ = streamFilter;
-  sinkFilterOnly_ =
-    util::endsWith(streamFilter_->getName(), SinkStreamFilter::NAME);
+  const std::string& name = streamFilter_->getName();
+  sinkFilterOnly_ = util::endsWith(name, SinkStreamFilter::NAME);
 }
 
 bool HttpSkipResponseCommand::executeInternal()
@@ -124,7 +124,7 @@ bool HttpSkipResponseCommand::executeInternal()
         if(totalLength_ > 0) {
           bufSize = std::min
             (totalLength_-receivedBytes_,
-             static_cast<uint64_t>(getSocketRecvBuffer()->getBufferLength()));
+             static_cast<off_t>(getSocketRecvBuffer()->getBufferLength()));
         } else {
           bufSize = getSocketRecvBuffer()->getBufferLength();
         }
@@ -186,7 +186,7 @@ bool HttpSkipResponseCommand::processResponse()
 {
   int statusCode;
   if(httpResponse_->isRedirect()) {
-    unsigned int rnum =
+    int rnum =
       httpResponse_->getHttpRequest()->getRequest()->getRedirectCount();
     if(rnum >= Request::MAX_REDIRECT) {
       throw DL_ABORT_EX2(fmt("Too many redirects: count=%u", rnum),
