@@ -49,63 +49,56 @@
 
 namespace aria2 {
 
-#define BUFSIZE (256*1024)
-#define ALIGNMENT 512
-
 IteratableChecksumValidator::IteratableChecksumValidator
 (const SharedHandle<DownloadContext>& dctx,
  const PieceStorageHandle& pieceStorage)
   : dctx_(dctx),
     pieceStorage_(pieceStorage),
-    currentOffset_(0),
-    buffer_(0)
+    currentOffset_(0)
 {}
 
-IteratableChecksumValidator::~IteratableChecksumValidator()
-{
-  delete [] buffer_;
-}
+IteratableChecksumValidator::~IteratableChecksumValidator() {}
 
 void IteratableChecksumValidator::validateChunk()
 {
-  if(!finished()) {
-    size_t length = pieceStorage_->getDiskAdaptor()->readData(buffer_,
-                                                              BUFSIZE,
-                                                              currentOffset_);
-    ctx_->update(buffer_, length);
-    currentOffset_ += length;
-    if(finished()) {
-      std::string actualDigest = ctx_->hexDigest();
-      if(dctx_->getDigest() == actualDigest) {
-        pieceStorage_->markAllPiecesDone();
-      } else {
-        A2_LOG_INFO(fmt("Checksum validation failed. expected=%s, actual=%s",
-                        dctx_->getDigest().c_str(), actualDigest.c_str()));
-        BitfieldMan bitfield(dctx_->getPieceLength(), dctx_->getTotalLength());
-        pieceStorage_->setBitfield(bitfield.getBitfield(), bitfield.getBitfieldLength());
-      }
+  // Don't guard with !finished() to allow zero-length file to be
+  // verified.
+  unsigned char buf[4096];
+  size_t length = pieceStorage_->getDiskAdaptor()->readData
+    (buf, sizeof(buf), currentOffset_);
+  ctx_->update(buf, length);
+  currentOffset_ += length;
+  if(finished()) {
+    std::string actualDigest = ctx_->digest();
+    if(dctx_->getDigest() == actualDigest) {
+      pieceStorage_->markAllPiecesDone();
+      dctx_->setChecksumVerified(true);
+    } else {
+      A2_LOG_INFO(fmt("Checksum validation failed. expected=%s, actual=%s",
+                      util::toHex(dctx_->getDigest()).c_str(),
+                      util::toHex(actualDigest).c_str()));
+      BitfieldMan bitfield(dctx_->getPieceLength(), dctx_->getTotalLength());
+      pieceStorage_->setBitfield(bitfield.getBitfield(), bitfield.getBitfieldLength());
     }
   }
 }
 
 bool IteratableChecksumValidator::finished() const
 {
-  if((uint64_t)currentOffset_ >= dctx_->getTotalLength()) {
+  if(currentOffset_ >= dctx_->getTotalLength()) {
     return true;
   } else {
     return false;
   }
 }
 
-uint64_t IteratableChecksumValidator::getTotalLength() const
+off_t IteratableChecksumValidator::getTotalLength() const
 {
   return dctx_->getTotalLength();
 }
 
 void IteratableChecksumValidator::init()
 {
-  delete [] buffer_;
-  buffer_ = new unsigned char[BUFSIZE];
   currentOffset_ = 0;
   ctx_ = MessageDigest::create(dctx_->getHashType());
 }
