@@ -37,13 +37,14 @@
 
 #include "IteratableValidator.h"
 
+#include <string>
+
 namespace aria2 {
 
 class DownloadContext;
 class PieceStorage;
 class BitfieldMan;
-class Logger;
-class MessageDigestContext;
+class MessageDigest;
 
 class IteratableChunkChecksumValidator:public IteratableValidator
 {
@@ -52,9 +53,7 @@ private:
   SharedHandle<PieceStorage> pieceStorage_;
   SharedHandle<BitfieldMan> bitfield_;
   size_t currentIndex_;
-  Logger* logger_;
-  SharedHandle<MessageDigestContext> ctx_;
-  unsigned char* buffer_;
+  SharedHandle<MessageDigest> ctx_;
 
   std::string calculateActualChecksum();
 
@@ -74,7 +73,7 @@ public:
 
   virtual off_t getCurrentOffset() const;
 
-  virtual uint64_t getTotalLength() const;
+  virtual off_t getTotalLength() const;
 };
 
 typedef SharedHandle<IteratableChunkChecksumValidator> IteratableChunkChecksumValidatorHandle;
