@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_METALINK_PARSER_STATE_H_
-#define _D_METALINK_PARSER_STATE_H_
+#ifndef D_METALINK_PARSER_STATE_H
+#define D_METALINK_PARSER_STATE_H
 
 #include "common.h"
 
@@ -43,13 +43,7 @@
 namespace aria2 {
 
 class MetalinkParserStateMachine;
-
-struct XmlAttr {
-  std::string localname;
-  std::string prefix;
-  std::string nsUri;
-  std::string value;
-};
+class XmlAttr;
 
 class MetalinkParserState
 {
@@ -58,16 +52,16 @@ public:
 
   virtual void beginElement
   (MetalinkParserStateMachine* stm,
-   const std::string& localname,
-   const std::string& prefix,
-   const std::string& nsUri,
+   const char* localname,
+   const char* prefix,
+   const char* nsUri,
    const std::vector<XmlAttr>& attrs) {}
   
   virtual void endElement
   (MetalinkParserStateMachine* stm,
-   const std::string& localname,
-   const std::string& prefix,
-   const std::string& nsUri,
+   const char* localname,
+   const char* prefix,
+   const char* nsUri,
    const std::string& characters) {}
 
   virtual bool needsCharactersBuffering() const
@@ -78,4 +72,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_METALINK_PARSER_STATE_H_
+#endif // D_METALINK_PARSER_STATE_H
