@@ -34,7 +34,8 @@
 /* copyright --> */
 #include "NsCookieParser.h"
 
-#include <fstream>
+#include <cstdio>
+#include <cstring>
 #include <limits>
 
 #include "util.h"
@@ -43,6 +44,8 @@
 #include "fmt.h"
 #include "Cookie.h"
 #include "cookie_helper.h"
+#include "BufferedFile.h"
+#include "array_fun.h"
 
 namespace aria2 {
 
@@ -50,25 +53,23 @@ NsCookieParser::NsCookieParser() {}
 
 NsCookieParser::~NsCookieParser() {}
 
-namespace {
-const std::string C_TRUE("TRUE");
-} // namespace
-
 namespace {
 bool parseNsCookie
-(Cookie& cookie, const std::string& nsCookieStr, time_t creationTime)
+(Cookie& cookie, const char* buf, size_t buflen, time_t creationTime)
 {
-  std::vector<std::string> vs;
-  util::split(nsCookieStr, std::back_inserter(vs), "\t", true);
+  std::vector<Scip> vs;
+  util::splitIter(&buf[0], &buf[buflen], std::back_inserter(vs), '\t', true);
   if(vs.size() < 6) {
     return false;
   }
-  std::string cookieDomain = cookie::removePrecedingDots(vs[0]);
-  if(vs[5].empty() || cookieDomain.empty() || !cookie::goodPath(vs[2])) {
+  vs[0].first = util::lstripIter(vs[0].first, vs[0].second, '.');
+  if(vs[5].first == vs[5].second || vs[0].first == vs[0].second ||
+     !cookie::goodPath(vs[2].first, vs[2].second)) {
     return false;
   }
   int64_t expiryTime;
-  if(!util::parseLLIntNoThrow(expiryTime, vs[4])) {
+  if(!util::parseLLIntNoThrow(expiryTime,
+                              std::string(vs[4].first, vs[4].second))) {
     return false;
   }
   if(std::numeric_limits<time_t>::max() < expiryTime) {
@@ -76,16 +77,21 @@ bool parseNsCookie
   } else if(std::numeric_limits<time_t>::min() > expiryTime) {
     expiryTime = std::numeric_limits<time_t>::min();
   }
-  cookie.setName(vs[5]);
-  cookie.setValue(vs.size() >= 7? vs[6]:A2STR::NIL);
+  cookie.setName(vs[5].first, vs[5].second);
+  if(vs.size() >= 7) {
+    cookie.setValue(vs[6].first, vs[6].second);
+  } else {
+    cookie.setValue(A2STR::NIL.begin(), A2STR::NIL.end());
+  }
   cookie.setExpiryTime(expiryTime == 0?
                        std::numeric_limits<time_t>::max():expiryTime);
   // aria2 treats expiryTime == 0 means session cookie.
   cookie.setPersistent(expiryTime != 0);
-  cookie.setDomain(cookieDomain);
-  cookie.setHostOnly(util::isNumericHost(cookieDomain) || vs[1] != C_TRUE);
-  cookie.setPath(vs[2]);
-  cookie.setSecure(vs[3] == C_TRUE);
+  cookie.setDomain(vs[0].first, vs[0].second);
+  cookie.setHostOnly(util::isNumericHost(cookie.getDomain()) ||
+                     !util::streq(vs[1].first, vs[1].second, "TRUE"));
+  cookie.setPath(vs[2].first, vs[2].second);
+  cookie.setSecure(util::streq(vs[3].first, vs[3].second, "TRUE"));
   cookie.setCreationTime(creationTime);
   return true;
 }
@@ -94,18 +100,22 @@ bool parseNsCookie
 std::vector<Cookie> NsCookieParser::parse
 (const std::string& filename, time_t creationTime)
 {
-  std::ifstream s(filename.c_str(), std::ios::binary);
-  if(!s) {
+  BufferedFile fp(filename, BufferedFile::READ);
+  if(!fp) {
     throw DL_ABORT_EX(fmt("Failed to open file %s", filename.c_str()));
   }
-  std::string line;
   std::vector<Cookie> cookies;
-  while(getline(s, line)) {
-    if(util::startsWith(line, A2STR::SHARP_C)) {
+  char buf[8192];
+  while(1) {
+    if(!fp.getsn(buf, sizeof(buf))) {
+      break;
+    }
+    size_t len = strlen(buf);
+    if(len == 0 || buf[0] == '#') {
       continue;
     }
     Cookie c;
-    if(parseNsCookie(c, line, creationTime)) {
+    if(parseNsCookie(c, buf, len, creationTime)) {
       cookies.push_back(c);
     }
   }
