@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -40,37 +40,29 @@
 namespace aria2 {
 
 RangeBtMessage::RangeBtMessage(uint8_t id,
-			       const std::string& name,
-			       size_t index, uint32_t begin, size_t length)
+                               const std::string& name,
+                               size_t index, int32_t begin, int32_t length)
   :SimpleBtMessage(id, name),
-   _index(index),
-   _begin(begin),
-   _length(length),
-   _msg(0) {}
+   index_(index),
+   begin_(begin),
+   length_(length) {}
 
-RangeBtMessage::~RangeBtMessage()
+unsigned char* RangeBtMessage::createMessage()
 {
-  delete [] _msg;
-}
-
-const unsigned char* RangeBtMessage::getMessage()
-{
-  if(!_msg) {
-    /**
-     * len --- 13, 4bytes
-     * id --- ?, 1byte
-     * index --- index, 4bytes
-     * begin --- begin, 4bytes
-     * length -- length, 4bytes
-     * total: 17bytes
-     */
-    _msg = new unsigned char[MESSAGE_LENGTH];
-    bittorrent::createPeerMessageString(_msg, MESSAGE_LENGTH, 13, getId());
-    bittorrent::setIntParam(&_msg[5], _index);
-    bittorrent::setIntParam(&_msg[9], _begin);
-    bittorrent::setIntParam(&_msg[13], _length);
-  }
-  return _msg;
+  /**
+   * len --- 13, 4bytes
+   * id --- ?, 1byte
+   * index --- index, 4bytes
+   * begin --- begin, 4bytes
+   * length -- length, 4bytes
+   * total: 17bytes
+   */
+  unsigned char* msg = new unsigned char[MESSAGE_LENGTH];
+  bittorrent::createPeerMessageString(msg, MESSAGE_LENGTH, 13, getId());
+  bittorrent::setIntParam(&msg[5], index_);
+  bittorrent::setIntParam(&msg[9], begin_);
+  bittorrent::setIntParam(&msg[13], length_);
+  return msg;
 }
 
 size_t RangeBtMessage::getMessageLength()
@@ -80,9 +72,10 @@ size_t RangeBtMessage::getMessageLength()
 
 std::string RangeBtMessage::toString() const
 {
-  return strconcat(getName(), " index=", util::uitos(_index),
-		   ", begin=", util::uitos(_begin),
-		   ", length=", util::uitos(_length));
+  return fmt("%s index=%lu, begin=%d, length=%d",
+             getName().c_str(),
+             static_cast<unsigned long>(index_),
+             begin_, length_);
 }
 
 } // namespace aria2
