@@ -76,6 +76,37 @@ const T* checkRequiredParam(const RpcRequest& req, size_t index)
   return checkParam<T>(req, index, true);
 }
 
+struct IntegerGE {
+  IntegerGE(int32_t min):min(min) {}
+
+  bool operator()(const Integer* param, std::string* error) const
+  {
+    if(min <= param->i()) {
+      return true;
+    } else {
+      if(error) {
+        *error = fmt("the value must be greater than or equal to %d.", min);
+      }
+      return false;
+    }
+  }
+
+  int32_t min;
+};
+
+template<typename Validator>
+const Integer* checkRequiredInteger(const RpcRequest& req, size_t index,
+                                    Validator validator)
+{
+  const Integer* param = checkRequiredParam<Integer>(req, index);
+  std::string error;
+  if(!validator(param, &error)) {
+    throw DL_ABORT_EX(fmt("The integer parameter at %lu has invalid value: %s",
+                          static_cast<unsigned long>(index), error.c_str()));
+  }
+  return param;
+}
+
 template<typename OutputIterator>
 void toStringList(OutputIterator out, const List* src)
 {
@@ -331,11 +362,11 @@ private:
   template<typename InputIterator>
   std::pair<InputIterator, InputIterator>
   getPaginationRange
-  (int offset, int num, InputIterator first, InputIterator last)
+  (int64_t offset, int64_t num, InputIterator first, InputIterator last)
   {
-    int size = std::distance(first, last);
+    int64_t size = std::distance(first, last);
     if(offset < 0) {
-      int tempoffset = offset+size;
+      int64_t tempoffset = offset+size;
       if(tempoffset < 0) {
         return std::make_pair(last, last);
       }
@@ -347,7 +378,7 @@ private:
     } else if(size <= offset) {
       return std::make_pair(last, last);
     }
-    int lastDistance;
+    int64_t lastDistance;
     if(size < offset+num) {
       lastDistance = size;
     } else {
@@ -363,14 +394,11 @@ protected:
   (const RpcRequest& req, DownloadEngine* e)
   {
     const Integer* offsetParam = checkRequiredParam<Integer>(req, 0);
-    const Integer* numParam = checkRequiredParam<Integer>(req, 1);
+    const Integer* numParam = checkRequiredInteger(req, 1, IntegerGE(0));
     const List* keysParam = checkParam<List>(req, 2);
 
-    if(numParam->i() < 0) {
-      throw DL_ABORT_EX("The parameter num must be zero or positive integer.");
-    }
-    int offset = offsetParam->i();
-    int num = numParam->i();
+    int64_t offset = offsetParam->i();
+    int64_t num = numParam->i();
     std::vector<std::string> keys;
     toStringList(std::back_inserter(keys), keysParam);
     const std::deque<SharedHandle<T> >& items = getItems(e);
