@@ -43,12 +43,12 @@ namespace rpc {
 
 class InitialXmlRpcRequestParserState:public XmlRpcRequestParserState {
 public:
-  virtual void beginElement(XmlRpcRequestParserStateMachine* stm,
-                            const std::string& name,
-                            const std::map<std::string, std::string>& attrs);
+  virtual void beginElement(XmlRpcRequestParserStateMachine* psm,
+                            const char* name,
+                            const std::vector<XmlAttr>& attrs);
   
-  virtual void endElement(XmlRpcRequestParserStateMachine* stm,
-                          const std::string& name,
+  virtual void endElement(XmlRpcRequestParserStateMachine* psm,
+                          const char* name,
                           const std::string& characters);
 
   virtual bool needsCharactersBuffering() const { return false; }
@@ -56,12 +56,12 @@ public:
 
 class UnknownElementXmlRpcRequestParserState:public XmlRpcRequestParserState {
 public:
-  virtual void beginElement(XmlRpcRequestParserStateMachine* stm,
-                            const std::string& name,
-                            const std::map<std::string, std::string>& attrs);
+  virtual void beginElement(XmlRpcRequestParserStateMachine* psm,
+                            const char* name,
+                            const std::vector<XmlAttr>& attrs);
   
-  virtual void endElement(XmlRpcRequestParserStateMachine* stm,
-                          const std::string& name,
+  virtual void endElement(XmlRpcRequestParserStateMachine* psm,
+                          const char* name,
                           const std::string& characters) {}
 
   virtual bool needsCharactersBuffering() const { return false; }
@@ -69,12 +69,12 @@ public:
 
 class MethodCallXmlRpcRequestParserState:public XmlRpcRequestParserState {
 public:
-  virtual void beginElement(XmlRpcRequestParserStateMachine* stm,
-                            const std::string& name,
-                            const std::map<std::string, std::string>& attrs);
+  virtual void beginElement(XmlRpcRequestParserStateMachine* psm,
+                            const char* name,
+                            const std::vector<XmlAttr>& attrs);
   
-  virtual void endElement(XmlRpcRequestParserStateMachine* stm,
-                          const std::string& name,
+  virtual void endElement(XmlRpcRequestParserStateMachine* psm,
+                          const char* name,
                           const std::string& characters) {}
 
   virtual bool needsCharactersBuffering() const { return false; }
@@ -82,152 +82,152 @@ public:
 
 class MethodNameXmlRpcRequestParserState:public XmlRpcRequestParserState {
 public:
-  virtual void beginElement(XmlRpcRequestParserStateMachine* stm,
-                            const std::string& name,
-                            const std::map<std::string, std::string>& attrs);
+  virtual void beginElement(XmlRpcRequestParserStateMachine* psm,
+                            const char* name,
+                            const std::vector<XmlAttr>& attrs);
   
-  virtual void endElement(XmlRpcRequestParserStateMachine* stm,
-                          const std::string& name,
+  virtual void endElement(XmlRpcRequestParserStateMachine* psm,
+                          const char* name,
                           const std::string& characters);
 
   virtual bool needsCharactersBuffering() const { return true; }
 };
 
 class ParamsXmlRpcRequestParserState:public XmlRpcRequestParserState {
-  virtual void beginElement(XmlRpcRequestParserStateMachine* stm,
-                            const std::string& name,
-                            const std::map<std::string, std::string>& attrs);
+  virtual void beginElement(XmlRpcRequestParserStateMachine* psm,
+                            const char* name,
+                            const std::vector<XmlAttr>& attrs);
   
-  virtual void endElement(XmlRpcRequestParserStateMachine* stm,
-                          const std::string& name,
+  virtual void endElement(XmlRpcRequestParserStateMachine* psm,
+                          const char* name,
                           const std::string& characters) {}
 
   virtual bool needsCharactersBuffering() const { return false; }
 };
 
 class ParamXmlRpcRequestParserState:public XmlRpcRequestParserState {
-  virtual void beginElement(XmlRpcRequestParserStateMachine* stm,
-                            const std::string& name,
-                            const std::map<std::string, std::string>& attrs);
+  virtual void beginElement(XmlRpcRequestParserStateMachine* psm,
+                            const char* name,
+                            const std::vector<XmlAttr>& attrs);
   
-  virtual void endElement(XmlRpcRequestParserStateMachine* stm,
-                          const std::string& name,
+  virtual void endElement(XmlRpcRequestParserStateMachine* psm,
+                          const char* name,
                           const std::string& characters);
 
   virtual bool needsCharactersBuffering() const { return false; }
 };
 
 class ValueXmlRpcRequestParserState:public XmlRpcRequestParserState {
-  virtual void beginElement(XmlRpcRequestParserStateMachine* stm,
-                            const std::string& name,
-                            const std::map<std::string, std::string>& attrs);
+  virtual void beginElement(XmlRpcRequestParserStateMachine* psm,
+                            const char* name,
+                            const std::vector<XmlAttr>& attrs);
 protected:
-  virtual void endElement(XmlRpcRequestParserStateMachine* stm,
-                          const std::string& name,
+  virtual void endElement(XmlRpcRequestParserStateMachine* psm,
+                          const char* name,
                           const std::string& characters);
 
   virtual bool needsCharactersBuffering() const { return true; }
 };
 
 class IntXmlRpcRequestParserState:public XmlRpcRequestParserState {
-  virtual void beginElement(XmlRpcRequestParserStateMachine* stm,
-                            const std::string& name,
-                            const std::map<std::string, std::string>& attrs);
+  virtual void beginElement(XmlRpcRequestParserStateMachine* psm,
+                            const char* name,
+                            const std::vector<XmlAttr>& attrs);
   
-  virtual void endElement(XmlRpcRequestParserStateMachine* stm,
-                          const std::string& name,
+  virtual void endElement(XmlRpcRequestParserStateMachine* psm,
+                          const char* name,
                           const std::string& characters);
 
   virtual bool needsCharactersBuffering() const { return true; }
 };
 
 class StringXmlRpcRequestParserState:public XmlRpcRequestParserState {
-  virtual void beginElement(XmlRpcRequestParserStateMachine* stm,
-                            const std::string& name,
-                            const std::map<std::string, std::string>& attrs);
+  virtual void beginElement(XmlRpcRequestParserStateMachine* psm,
+                            const char* name,
+                            const std::vector<XmlAttr>& attrs);
   
-  virtual void endElement(XmlRpcRequestParserStateMachine* stm,
-                          const std::string& name,
+  virtual void endElement(XmlRpcRequestParserStateMachine* psm,
+                          const char* name,
                           const std::string& characters);
 
   virtual bool needsCharactersBuffering() const { return true; }
 };
 
 class Base64XmlRpcRequestParserState:public XmlRpcRequestParserState {
-  virtual void beginElement(XmlRpcRequestParserStateMachine* stm,
-                            const std::string& name,
-                            const std::map<std::string, std::string>& attrs);
+  virtual void beginElement(XmlRpcRequestParserStateMachine* psm,
+                            const char* name,
+                            const std::vector<XmlAttr>& attrs);
   
-  virtual void endElement(XmlRpcRequestParserStateMachine* stm,
-                          const std::string& name,
+  virtual void endElement(XmlRpcRequestParserStateMachine* psm,
+                          const char* name,
                           const std::string& characters);
 
   virtual bool needsCharactersBuffering() const { return true; }
 };
 
 class StructXmlRpcRequestParserState:public XmlRpcRequestParserState {
-  virtual void beginElement(XmlRpcRequestParserStateMachine* stm,
-                            const std::string& name,
-                            const std::map<std::string, std::string>& attrs);
+  virtual void beginElement(XmlRpcRequestParserStateMachine* psm,
+                            const char* name,
+                            const std::vector<XmlAttr>& attrs);
   
-  virtual void endElement(XmlRpcRequestParserStateMachine* stm,
-                          const std::string& name,
+  virtual void endElement(XmlRpcRequestParserStateMachine* psm,
+                          const char* name,
                           const std::string& characters) {}
 
   virtual bool needsCharactersBuffering() const { return false; }
 };
 
 class MemberXmlRpcRequestParserState:public XmlRpcRequestParserState {
-  virtual void beginElement(XmlRpcRequestParserStateMachine* stm,
-                            const std::string& name,
-                            const std::map<std::string, std::string>& attrs);
+  virtual void beginElement(XmlRpcRequestParserStateMachine* psm,
+                            const char* name,
+                            const std::vector<XmlAttr>& attrs);
   
-  virtual void endElement(XmlRpcRequestParserStateMachine* stm,
-                          const std::string& name,
+  virtual void endElement(XmlRpcRequestParserStateMachine* psm,
+                          const char* name,
                           const std::string& characters);
 
   virtual bool needsCharactersBuffering() const { return false; }
 };
 
 class NameXmlRpcRequestParserState:public XmlRpcRequestParserState {
-  virtual void beginElement(XmlRpcRequestParserStateMachine* stm,
-                            const std::string& name,
-                            const std::map<std::string, std::string>& attrs);
+  virtual void beginElement(XmlRpcRequestParserStateMachine* psm,
+                            const char* name,
+                            const std::vector<XmlAttr>& attrs);
   
-  virtual void endElement(XmlRpcRequestParserStateMachine* stm,
-                          const std::string& name,
+  virtual void endElement(XmlRpcRequestParserStateMachine* psm,
+                          const char* name,
                           const std::string& characters);
 
   virtual bool needsCharactersBuffering() const { return true; }
 };
 
 class ArrayXmlRpcRequestParserState:public XmlRpcRequestParserState {
-  virtual void beginElement(XmlRpcRequestParserStateMachine* stm,
-                            const std::string& name,
-                            const std::map<std::string, std::string>& attrs);
+  virtual void beginElement(XmlRpcRequestParserStateMachine* psm,
+                            const char* name,
+                            const std::vector<XmlAttr>& attrs);
   
-  virtual void endElement(XmlRpcRequestParserStateMachine* stm,
-                          const std::string& name,
+  virtual void endElement(XmlRpcRequestParserStateMachine* psm,
+                          const char* name,
                           const std::string& characters) {}
 
   virtual bool needsCharactersBuffering() const { return false; }
 };
 
 class DataXmlRpcRequestParserState:public XmlRpcRequestParserState {
-  virtual void beginElement(XmlRpcRequestParserStateMachine* stm,
-                            const std::string& name,
-                            const std::map<std::string, std::string>& attrs);
+  virtual void beginElement(XmlRpcRequestParserStateMachine* psm,
+                            const char* name,
+                            const std::vector<XmlAttr>& attrs);
   
-  virtual void endElement(XmlRpcRequestParserStateMachine* stm,
-                          const std::string& name,
+  virtual void endElement(XmlRpcRequestParserStateMachine* psm,
+                          const char* name,
                           const std::string& characters) {}
 
   virtual bool needsCharactersBuffering() const { return false; }
 };
 
 class ArrayValueXmlRpcRequestParserState:public ValueXmlRpcRequestParserState {
-  virtual void endElement(XmlRpcRequestParserStateMachine* stm,
-                          const std::string& name,
+  virtual void endElement(XmlRpcRequestParserStateMachine* psm,
+                          const char* name,
                           const std::string& characters);
 };
 
