@@ -31,8 +31,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_A2NETCOMPAT_H_
-#define _D_A2NETCOMPAT_H_
+#ifndef D_A2NETCOMPAT_H
+#define D_A2NETCOMPAT_H
 
 #include "a2io.h"
 
@@ -106,6 +106,12 @@
 
 #define DEFAULT_AI_FLAGS AI_ADDRCONFIG
 
+#ifdef __MINGW32__
+# ifndef SHUT_WR
+#  define SHUT_WR SD_SEND
+# endif // !SHUT_WR
+#endif // __MINGW32__
+
 #ifdef __MINGW32__
 template<typename T>
 class wsaapi_auto_delete {
@@ -126,4 +132,11 @@ public:
 # define WSAAPI_AUTO_DELETE auto_delete
 #endif // !__MINGW32__
 
-#endif // _D_A2NETCOMPAT_H_
+union sockaddr_union {
+  sockaddr sa;
+  sockaddr_storage storage;
+  sockaddr_in6 in6;
+  sockaddr_in in;
+};
+
+#endif // D_A2NETCOMPAT_H
