@@ -2,6 +2,7 @@
 
 #include <cppunit/extensions/HelperMacros.h>
 
+#include "TestUtil.h"
 #include "DownloadContext.h"
 #include "DefaultPieceStorage.h"
 #include "Option.h"
@@ -19,7 +20,7 @@ class IteratableChunkChecksumValidatorTest:public CppUnit::TestFixture {
   CPPUNIT_TEST_SUITE_END();
 private:
 
-  static const char* csArray[];
+  static const std::string csArray[];
 public:
   void setUp() {
   }
@@ -31,19 +32,20 @@ public:
 
 CPPUNIT_TEST_SUITE_REGISTRATION( IteratableChunkChecksumValidatorTest );
 
-const char* IteratableChunkChecksumValidatorTest::csArray[] = { "29b0e7878271645fffb7eec7db4a7473a1c00bc1",
-                                                                "4df75a661cb7eb2733d9cdaa7f772eae3a4e2976",
-                                                                "0a4ea2f7dd7c52ddf2099a444ab2184b4d341bdb" };
+const std::string IteratableChunkChecksumValidatorTest::csArray[] =
+  { fromHex("29b0e7878271645fffb7eec7db4a7473a1c00bc1"),
+    fromHex("4df75a661cb7eb2733d9cdaa7f772eae3a4e2976"),
+    fromHex("0a4ea2f7dd7c52ddf2099a444ab2184b4d341bdb") };
 
 void IteratableChunkChecksumValidatorTest::testValidate() {
   Option option;
   SharedHandle<DownloadContext> dctx
-    (new DownloadContext(100, 250, "chunkChecksumTestFile250.txt"));
-  dctx->setPieceHashes(&csArray[0], &csArray[3]);
-  dctx->setPieceHashAlgo("sha1");
+    (new DownloadContext(100, 250, A2_TEST_DIR"/chunkChecksumTestFile250.txt"));
+  dctx->setPieceHashes("sha-1", &csArray[0], &csArray[3]);
   SharedHandle<DefaultPieceStorage> ps
     (new DefaultPieceStorage(dctx, &option));
   ps->initStorage();
+  ps->getDiskAdaptor()->enableReadOnly();
   ps->getDiskAdaptor()->openFile();
 
   IteratableChunkChecksumValidator validator(dctx, ps);
@@ -59,8 +61,8 @@ void IteratableChunkChecksumValidatorTest::testValidate() {
 
   // make the test fail
   std::deque<std::string> badHashes(&csArray[0], &csArray[3]);
-  badHashes[1] = "ffffffffffffffffffffffffffffffffffffffff";
-  dctx->setPieceHashes(badHashes.begin(), badHashes.end());
+  badHashes[1] = fromHex("ffffffffffffffffffffffffffffffffffffffff");
+  dctx->setPieceHashes("sha-1", badHashes.begin(), badHashes.end());
 
   validator.init();
 
@@ -75,14 +77,14 @@ void IteratableChunkChecksumValidatorTest::testValidate() {
 void IteratableChunkChecksumValidatorTest::testValidate_readError() {
   Option option;
   SharedHandle<DownloadContext> dctx
-    (new DownloadContext(100, 500, "chunkChecksumTestFile250.txt"));
+    (new DownloadContext(100, 500, A2_TEST_DIR"/chunkChecksumTestFile250.txt"));
   std::deque<std::string> hashes(&csArray[0], &csArray[3]);
-  hashes.push_back("ffffffffffffffffffffffffffffffffffffffff");
-  hashes.push_back("ffffffffffffffffffffffffffffffffffffffff");
-  dctx->setPieceHashes(hashes.begin(), hashes.end());
-  dctx->setPieceHashAlgo("sha1");
+  hashes.push_back(fromHex("ffffffffffffffffffffffffffffffffffffffff"));
+  hashes.push_back(fromHex("ffffffffffffffffffffffffffffffffffffffff"));
+  dctx->setPieceHashes("sha-1", hashes.begin(), hashes.end());
   SharedHandle<DefaultPieceStorage> ps(new DefaultPieceStorage(dctx, &option));
   ps->initStorage();
+  ps->getDiskAdaptor()->enableReadOnly();
   ps->getDiskAdaptor()->openFile();
 
   IteratableChunkChecksumValidator validator(dctx, ps);
