@@ -1,5 +1,5 @@
-#ifndef _D_MOCK_DHT_MESSAGE_FACTORY_H_
-#define _D_MOCK_DHT_MESSAGE_FACTORY_H_
+#ifndef D_MOCK_DHT_MESSAGE_FACTORY_H
+#define D_MOCK_DHT_MESSAGE_FACTORY_H
 
 #include "DHTMessageFactory.h"
 #include "DHTNode.h"
@@ -33,7 +33,7 @@ public:
     remoteNode->setPort(port);
     SharedHandle<MockDHTResponseMessage> m
       (new MockDHTResponseMessage(localNode_, remoteNode,
-                                  asString(dict->get("t"))->s()));
+                                  downcast<String>(dict->get("t"))->s()));
     return m;
   }
 
@@ -120,4 +120,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_MOCK_DHT_MESSAGE_FACTORY_H_
+#endif // D_MOCK_DHT_MESSAGE_FACTORY_H
